@@ -19,44 +19,22 @@ describe RDoc::Generator::SDoc do
   it "should parse github option" do
     assert !@options.github
 
-    out, err = capture_io do
+    _, err = capture_io do
       @parser.parse %w[--github]
     end
 
-    err.wont_match /^invalid options/
+    err.wont_match(/^invalid options/)
     @options.github.must_equal true
   end
 
   it "should parse github short-hand option" do
     assert !@options.github
 
-    out, err = capture_io do
+    _, err = capture_io do
       @parser.parse %w[-g]
     end
 
-    err.wont_match /^invalid options/
+    err.wont_match(/^invalid options/)
     @options.github.must_equal true
   end
-
-  it "should parse no search engine index option" do
-    @options.search_index.must_equal true
-
-    out, err = capture_io do
-      @parser.parse %w[--without-search]
-    end
-
-    err.wont_match /^invalid options/
-    @options.search_index.must_equal false
-  end
-
-  it "should parse search-index shorthand option" do
-    @options.search_index.must_equal true
-    out, err = capture_io do
-      @parser.parse %w[-s]
-    end
-
-    err.wont_match /^invalid options/
-    @options.search_index.must_equal false
-  end
-
 end
